@@ -1,6 +1,6 @@
 // This contains the implementation of the pyqtBoundSignal type.
 //
-// Copyright (c) 2021 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of PyQt6.
 // 
@@ -953,8 +953,11 @@ static void slot_signature_from_decorations(QByteArray &slot_signature,
             const Chimera *sig_arg = signal->parsed_arguments.at(a);
             const Chimera *slot_arg = slot->parsed_arguments.at(a);
 
-            // We simply compare meta-types.
-            if (sig_arg->metatype != slot_arg->metatype)
+            // We simply compare the C++ names. We used to compare meta-types
+            // but this is unreliable as the signal's type may have been
+            // registered by Qt internally (and so given a new meta-type) after
+            // the slot was defined (and has the meta-type of PyQt_PyObject).
+            if (sig_arg->name() != slot_arg->name())
             {
                 slot = 0;
                 break;
